import { Connection } from "./Connection";
import { ConnectionOptions } from "./ConnectionOptions";
/**
 * Connection manager holds all connections made to the databases and providers helper management functions
 * for all exist connections.
 */
export declare class ConnectionManager {
    /**
     * List of connections registered in this connection manager.
     */
    private connections;
    /**
     * Creates a new connection based on the given connection options and registers a new connection in the manager.
     */
    createAndConnect(options: ConnectionOptions): Promise<Connection>;
    /**
     * Creates a new connection based on the given connection options and registers this connection in the manager.
     * Note that dropSchemaOnConnection and autoSchemaCreate options of a ConnectionOptions are not working there - use
     * createAndConnect method to use them.
     */
    create(options: ConnectionOptions): Connection;
    /**
     * Gets registered connection with the given name.
     * If connection name is not given then it will get a default connection.
     */
    get(name?: string): Connection;
    /**
     * Creates a new driver based on the given driver type and options.
     */
    private createDriver(options);
    /**
     * Creates a new connection and registers it in the connection manager.
     */
    private createConnection(name, driver);
}
