import { Driver } from "./Driver";
import { SchemaBuilder } from "../schema-builder/SchemaBuilder";
import { BaseDriver } from "./BaseDriver";
import { DriverOptions } from "./DriverOptions";
import { ObjectLiteral } from "../common/ObjectLiteral";
import { DatabaseConnection } from "./DatabaseConnection";
/**
 * This driver organizes work with postgres database.
 */
export declare class PostgresDriver extends BaseDriver implements Driver {
    connectionOptions: DriverOptions;
    readonly isResultsLowercase: boolean;
    /**
     * Postgres library.
     */
    private postgres;
    /**
     * Connection to postgres database.
     */
    private postgresConnection;
    /**
     * Access to the native implementation of the database.
     */
    readonly native: any;
    /**
     * Access to the native connection to the database.
     */
    readonly nativeConnection: any;
    /**
     * Database name to which this connection is made.
     */
    readonly db: string;
    constructor(connectionOptions: DriverOptions, postgres?: any);
    retrieveDatabaseConnection(): Promise<DatabaseConnection>;
    releaseDatabaseConnection(dbConnection: DatabaseConnection): Promise<void>;
    /**
     * Creates a schema builder which can be used to build database/table schemas.
     */
    createSchemaBuilder(dbConnection: DatabaseConnection): SchemaBuilder;
    /**
     * Performs connection to the database based on given connection options.
     */
    connect(): Promise<void>;
    /**
     * Closes connection with database.
     */
    disconnect(): Promise<void>;
    /**
     * Escapes given value.
     */
    escape(dbConnection: DatabaseConnection, value: any): any;
    /**
     * Executes a given SQL query.
     */
    query<T>(dbConnection: DatabaseConnection, query: string, parameters?: any[]): Promise<T>;
    /**
     * Clears all tables in the currently connected database.
     */
    clearDatabase(dbConnection: DatabaseConnection): Promise<void>;
    buildParameters(sql: string, parameters: ObjectLiteral): any[];
    replaceParameters(sql: string, parameters: ObjectLiteral): string;
    /**
     * Insert a new row into given table.
     */
    insert(dbConnection: DatabaseConnection, tableName: string, keyValues: ObjectLiteral, idColumnName?: string): Promise<any>;
    /**
     * Updates rows that match given conditions in the given table.
     */
    update(dbConnection: DatabaseConnection, tableName: string, valuesMap: ObjectLiteral, conditions: ObjectLiteral): Promise<void>;
    /**
     * Deletes from the given table by a given conditions.
     */
    delete(dbConnection: DatabaseConnection, tableName: string, conditions: ObjectLiteral): Promise<void>;
    protected parametrizeObjectMap(objectMap: ObjectLiteral, startIndex?: number): string[];
    protected checkIfConnectionSet(): void;
}
